struct RenderWorker {Show 13 fields
ctx: WgpuContext,
renderer: Renderer,
render_textures: Vec<RenderTextures>,
pool: RenderPool,
clear_color: Color,
video_writer: Option<FileWriter>,
video_writer_builder: Option<FileWriterBuilder>,
save_frames: bool,
output_dir: PathBuf,
scene_name: String,
width: u32,
height: u32,
fps: u32,
}Available on non-
target_family=wasm and crate feature render only.Fields
ctx: WgpuContextrenderer: Rendererrender_textures: Vec<RenderTextures>pool: RenderPoolclear_color: Colorvideo_writer: Option<FileWriter>video_writer_builder: Option<FileWriterBuilder>save_frames: booloutput_dir: PathBufscene_name: Stringwidth: u32height: u32fps: u32Implementations
Sourceimpl RenderWorker
impl RenderWorker
fn new( scene_name: String, scene_config: &SceneConfig, output: &Output, buffer_count: usize, ) -> Self
fn save_frame_dir(&self) -> PathBuf
fn yeet(self) -> RenderThreadHandle
fn render_store(&mut self, store: &CoreItemStore)
Sourcefn output_frame_from(&mut self, target_idx: usize, frame_number: u64)
fn output_frame_from(&mut self, target_idx: usize, frame_number: u64)
Write and save (if Self::save_frames is true)
Sourcefn write_frame_from(&mut self, target_idx: usize)
fn write_frame_from(&mut self, target_idx: usize)
Write frame data from the given target to the video file.
Sourcefn save_frame_from(&mut self, target_idx: usize, frame_number: u64)
fn save_frame_from(&mut self, target_idx: usize, frame_number: u64)
Save frame from the given target as a PNG image.
Sourcepub fn capture_frame(&mut self, path: impl AsRef<Path>)
pub fn capture_frame(&mut self, path: impl AsRef<Path>)
Capture frame to image file (sync path, uses target 0).